@@ -29,15 +29,15 @@ An assortment of classes modeling specific features of the BrickPi.
 from .core import *
 
 
-OUTPUT_A = 'ttyAMA0:outA'
-OUTPUT_B = 'ttyAMA0:outB'
-OUTPUT_C = 'ttyAMA0:outC'
-OUTPUT_D = 'ttyAMA0:outD'
+OUTPUT_A = 'ttyAMA0:MA'
+OUTPUT_B = 'ttyAMA0:MB'
+OUTPUT_C = 'ttyAMA0:MC'
+OUTPUT_D = 'ttyAMA0:MD'
 
-INPUT_1 = 'ttyAMA0:in1'
-INPUT_2 = 'ttyAMA0:in2'
-INPUT_3 = 'ttyAMA0:in3'
-INPUT_4 = 'ttyAMA0:in4'
+INPUT_1 = 'ttyAMA0:S1'
+INPUT_2 = 'ttyAMA0:S2'
+INPUT_3 = 'ttyAMA0:S3'
+INPUT_4 = 'ttyAMA0:S4'
 
 
 class Leds(object):
@@ -47,12 +47,13 @@ class Leds(object):
 
 # ~autogen led-colors platforms.brickpi.led>currentClass
 
-    blue_one = Led(name='brickpi1:blue:ev3dev')
-    blue_two = Led(name='brickpi2:blue:ev3dev')
+    blue_led1 = Led(name_pattern='brickpi:led1:blue:ev3dev')
+    blue_led2 = Led(name_pattern='brickpi:led2:blue:ev3dev')
 
-    BLUE_ONE = ( blue_one, )
-    BLUE_TWO = ( blue_two, )
+    LED1 = ( blue_led1, )
+    LED2 = ( blue_led2, )
 
+    BLACK = ( 0, )
     BLUE = ( 1, )
 
     @staticmethod
@@ -87,8 +88,8 @@ class Leds(object):
         """
         Turn all leds off
         """
-        Leds.blue_one.brightness = 0
-        Leds.blue_two.brightness = 0
+        Leds.blue_led1.brightness = 0
+        Leds.blue_led2.brightness = 0
 
 
 # ~autogen
